Hi Joe,
In <ae6cb1100802262332o4b516cb6u208fd0cb3a6b74f0_at_mail.gmail.com>
"Re: Ruby bindings on trunk build failure" on Tue, 26 Feb 2008 23:32:03 -0800,
"Joe Swatosh" <joe.swatosh_at_gmail.com> wrote:
> I had a little time after all. Builds .24 .27 .31 .33. Tests passed
> .31 and .33. It looks like the way that SWIG handles NULLs
> changed.... The test failures have nothing to do with the patch.
What about the attached patch?
Thanks,
--
kou
Index: subversion/bindings/swig/ruby/libsvn_swig_ruby/swigutil_rb.c
===================================================================
--- subversion/bindings/swig/ruby/libsvn_swig_ruby/swigutil_rb.c (revision 29608)
+++ subversion/bindings/swig/ruby/libsvn_swig_ruby/swigutil_rb.c (working copy)
@@ -2,9 +2,6 @@
/* Tell swigutil_rb.h that we're inside the implementation */
#define SVN_SWIG_SWIGUTIL_RB_C
-#ifdef WIN32
-# include "rubyhead.swg"
-#endif
#include "swig_ruby_external_runtime.swg"
#include "swigutil_rb.h"
#include <st.h>
Index: subversion/bindings/swig/svn_client.i
===================================================================
--- subversion/bindings/swig/svn_client.i (revision 29608)
+++ subversion/bindings/swig/svn_client.i (working copy)
@@ -41,6 +41,7 @@
%apply const char *MAY_BE_NULL {
const char *native_eol,
const char *comment,
+ const char *relative_to_dir,
apr_array_header_t *changelists
};
Index: build/generator/swig/external_runtime.py
===================================================================
--- build/generator/swig/external_runtime.py (revision 29608)
+++ build/generator/swig/external_runtime.py (working copy)
@@ -57,13 +57,18 @@
else:
_exec.run("%s -%s -external-runtime %s" % (self.swig_path, lang, out))
- if lang == "ruby" and self.version() >= 103026 and self.version() < 103028:
- # SWIG 1.3.26-27 should include rubytracking.swg in their
- # external runtime, but they don't.
+ # SWIG 1.3.24-27 should include rubyhead.swg in their
+ # external runtime, but they don't.
+ if lang == "ruby" and self.version() < 103028:
runtime = open(out).read()
- tracking = open("%s/rubytracking.swg" % self.proxy_dir).read();
out_file = open(out, "w")
- out_file.write(tracking)
+ head = open("%s/rubyhead.swg" % self.proxy_dir).read();
+ out_file.write(head)
+ if self.version() >= 103026:
+ # SWIG 1.3.26-27 should include rubytracking.swg in their
+ # external runtime, but they don't.
+ tracking = open("%s/rubytracking.swg" % self.proxy_dir).read();
+ out_file.write(tracking)
out_file.write(runtime)
out_file.close()
---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe_at_subversion.tigris.org
For additional commands, e-mail: dev-help_at_subversion.tigris.org
Received on 2008-02-27 16:21:42 CET